@@ -5,14 +5,15 @@ package HTML::HTPL::Config;
 
 $mailprog = "/usr/sbin/sendmail";
 $ccprog = "/usr/bin/gcc";
-$dbgbin = "/home/ariel/./cgi-bin/htpldbg";
+$dbgbin = "/usr/home/schop/public_html/cgi-bin/htpldbg";
+$pcbin = "/usr/home/schop/public_html/cgi-bin/htplp";
 $temp = "/tmp";
 
 ###
 # Uncomment to allow persistency
 
 # $htpl_persistent = 1;
-# $htpl_db_file = "/home/ariel/./htpl/htpl.db";
+# $htpl_db_file = "/usr/home/schop/public_html/htpl/htpl.db";
 # $htpl_per_session_idle_time = 3600;
 # $htpl_persist_cachesize = 4;
 
@@ -35,7 +36,20 @@ $temp = "/tmp";
 
 ###
 # Security and system logs.
-$htpl_system_log = "/home/ariel/./.htpl.log";
+$htpl_system_log = "/usr/home/schop/public_html/.htpl.log";
+
+###
+# Locale. Currently supported via the DoW and MoY arrays
+$htpl_language = "English"; # Norwegian, Austrian, English, German,
+                            # Czech, French, Italian
+
+####
+# Comment to disable persistent DB connections under mod_perl
+$htpl_db_save = 1;
+
+####
+# HTPL PTS port
+$htpl_pts_port = 4002;
 
 ###
 # Put configuration for directories in htpl-site.pl in directories
